Module: Wordmove::Actions::Helpers

Overview

Helpers for Wordmove::Actions

All helpers methos are class methods; this way we force avoiding the use of persistence. All actions have to be approached more as functional code than OO code. Thus helpers are condidered as functional code too.