Module: Wordmove::Actions::Helpers
- Extended by:
- ActiveSupport::Concern
- Included in:
- AdaptLocalDb, AdaptRemoteDb, BackupLocalDb, DeleteLocalFile, DeleteRemoteFile, FilterAndSetupTasksToRun, Ftp::BackupRemoteDb, Ftp::CleanupAfterAdapt, Ftp::DownloadRemoteDb, Ftp::GetDirectory, Ftp::PullWordpress, Ftp::PushWordpress, Ftp::PutAndImportDumpRemotely, Ftp::PutDirectory, GetFile, PutFile, RunAfterPullHook, RunAfterPushHook, RunBeforePullHook, RunBeforePushHook, RunLocalCommand, SetupContextForDb, Ssh::BackupRemoteDb, Ssh::CleanupAfterAdapt, Ssh::DownloadRemoteDb, Ssh::GetDirectory, Ssh::PullWordpress, Ssh::PushWordpress, Ssh::PutAndImportDumpRemotely, Ssh::PutDirectory, Ssh::RunRemoteCommand, Organizers::Ftp::Pull, Organizers::Ftp::Push, Organizers::Ssh::Pull, Organizers::Ssh::Push
- Defined in:
- lib/wordmove/actions/helpers.rb
Overview
Helpers for Wordmove::Actions
All helpers methos are class methods; this way we force avoiding the use of persistence. All actions have to be approached more as functional code than OO code. Thus helpers are condidered as functional code too.